@@ -845,6 +845,12 @@ void       regress_test_obj_emit_sig_with_array_len_prop (RegressTestObj *obj);
 _GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_inout_int (RegressTestObj *obj);
 
+_GI_TEST_EXTERN
+void       regress_test_obj_emit_sig_with_error (RegressTestObj *self);
+
+_GI_TEST_EXTERN
+void       regress_test_obj_emit_sig_with_null_error (RegressTestObj *self);
+
 _GI_TEST_EXTERN
 int        regress_test_obj_instance_method (RegressTestObj *obj);
 
@@ -1503,4 +1509,22 @@ struct _RegressTestReferenceCounters {
   gatomicrefcount atomicrefcount;
 };
 
+_GI_TEST_EXTERN
+void regress_test_array_struct_out_none (RegressTestStructA **arr, gsize *len);
+
+_GI_TEST_EXTERN
+void regress_test_array_struct_out_container (RegressTestStructA **arr, gsize *len);
+
+_GI_TEST_EXTERN
+void regress_test_array_struct_out_full_fixed (RegressTestStructA **arr);
+
+_GI_TEST_EXTERN
+void regress_test_array_struct_out_caller_alloc (RegressTestStructA *arr, gsize len);
+
+_GI_TEST_EXTERN
+void regress_test_array_struct_in_full (RegressTestStructA *arr, gsize len);
+
+_GI_TEST_EXTERN
+void regress_test_array_struct_in_none (RegressTestStructA *arr, gsize len);
+
 #endif /* __GITESTTYPES_H__ */
